@@ -11,8 +11,10 @@ from ctypes import ArgumentError
 
 from shapely.coords import required
 from shapely.geos import lgeos
-from shapely.geometry.base import BaseMultipartGeometry, exceptNull
-from shapely.geometry.point import Point, geos_point_from_py
+from shapely.geometry.base import (
+    BaseMultipartGeometry, exceptNull, geos_geom_from_py
+)
+from shapely.geometry import point
 from shapely.geometry.proxy import CachingGeometryProxy
 
 __all__ = ['MultiPoint', 'asMultiPoint']
@@ -58,7 +60,7 @@ class MultiPoint(BaseMultipartGeometry):
             self._geom, self._ndim = geos_multipoint_from_py(points)
 
     def shape_factory(self, *args):
-        return Point(*args)
+        return point.Point(*args)
 
     @property
     def __geo_interface__(self):
@@ -157,6 +159,9 @@ def asMultiPoint(context):
 
 
 def geos_multipoint_from_py(ob):
+    if isinstance(ob, MultiPoint):
+        return geos_geom_from_py(ob)
+
     # If numpy is present, we use numpy.require to ensure that we have a
     # C-continguous array that owns its data. View data will be copied.
     ob = required(ob)
@@ -180,7 +185,7 @@ def geos_multipoint_from_py(ob):
         subs = (c_void_p * m)()
 
         for i in range(m):
-            geom, ndims = geos_point_from_py(cp[n*i:n*i+2])
+            geom, ndims = point.geos_point_from_py(cp[n*i:n*i+2])
             subs[i] = cast(geom, c_void_p)
 
     except AttributeError:
@@ -198,7 +203,7 @@ def geos_multipoint_from_py(ob):
         # add to coordinate sequence
         for i in range(m):
             coords = ob[i]
-            geom, ndims = geos_point_from_py(coords)
+            geom, ndims = point.geos_point_from_py(coords)
             subs[i] = cast(geom, c_void_p)
             
     return lgeos.GEOSGeom_createCollection(4, subs, m), n
